@@ -2,24 +2,25 @@
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QDate>
 
 #include <KI18n/KLocalizedString>
 
-#include "nota_version.h"
+#include "../nota_version.h"
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
+#include <MauiKit/Core/mauiandroid.h>
 #else
 #include <QApplication>
 #endif
 
-#include <MauiKit/mauiapp.h>
+#include <MauiKit/Core/mauiapp.h>
 
 #include "nota.h"
 
 // Models
-#include "src/models/documentsmodel.h"
-#include "src/models/historymodel.h"
+#include "models/historymodel.h"
 
 #define NOTA_URI "org.maui.nota"
 
@@ -39,21 +40,21 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif
 
     app.setOrganizationName(QStringLiteral("Maui"));
-    app.setWindowIcon(QIcon(":/nota.svg"));
+    app.setWindowIcon(QIcon(":/img/nota.svg"));
 
     MauiApp::instance()->setHandleAccounts(false); // for now nota can not handle cloud accounts
     MauiApp::instance()->setIconName("qrc:/img/nota.svg");
 
     KLocalizedString::setApplicationDomain("nota");
 
-    KAboutData about(QStringLiteral("nota"), i18n("Nota"), NOTA_VERSION_STRING, i18n("Nota allows you to browse, create, and edit simple and rich text files."), KAboutLicense::LGPL_V3,i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())));
+    KAboutData about(QStringLiteral("nota"), i18n("Nota"), NOTA_VERSION_STRING, i18n("Nota allows you to browse, create, and edit simple and rich text files."), KAboutLicense::LGPL_V3,i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.addAuthor(i18n("Anupam Basak"), i18n("Developer"), QStringLiteral("anupam.basak27@gmail.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/nota");
     about.setBugAddress("https://invent.kde.org/maui/nota/-/issues");
-    about.setOrganizationDomain("org.maui.nota");
+    about.setOrganizationDomain(NOTA_URI);
     about.setProgramLogo(app.windowIcon());
 
     KAboutData::setApplicationData(about);
@@ -81,7 +82,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     Qt::QueuedConnection);
 
     qmlRegisterSingletonInstance<Nota>(NOTA_URI, 1, 0, "Nota", Nota::instance());
-    qmlRegisterType<DocumentsModel>(NOTA_URI, 1, 0, "Documents");
     qmlRegisterType<HistoryModel>(NOTA_URI, 1, 0, "History");
 
     engine.load(url);
