@@ -3,13 +3,8 @@
 
 #include <QObject>
 
-#ifdef STATIC_MAUIKIT
-#include "fmh.h"
-#include "mauilist.h"
-#else
-#include <MauiKit/fmh.h>
-#include <MauiKit/mauilist.h>
-#endif
+#include <MauiKit/Core/fmh.h>
+#include <MauiKit/Core/mauilist.h>
 
 namespace FMH
 {
@@ -27,6 +22,9 @@ public:
 
     void componentComplete() override final;
 
+public slots:
+    int indexOfName(const QString &query);
+
 private:
     void append(const FMH::MODEL_LIST &items);
 
