@@ -1,13 +1,11 @@
 #include "historymodel.h"
-#ifdef STATIC_MAUIKIT
-#include "utils.h"
-#else
-#include <MauiKit/utils.h>
-#endif
+
+#include <MauiKit/Core/utils.h>
+#include <MauiKit/FileBrowsing/fmstatic.h>
 
 static bool isTextDocument(const QUrl &url)
 {
-    return FMH::checkFileType(FMH::FILTER_TYPE::TEXT, FMH::getMime(url));
+    return FMStatic::checkFileType(FMStatic::FILTER_TYPE::TEXT, FMStatic::getMime(url));
 }
 
 HistoryModel::HistoryModel(QObject *parent)
@@ -27,7 +25,7 @@ void HistoryModel::append(const QUrl &url)
         return;
 
     emit this->preItemAppended();
-    this->m_list << FMH::getFileInfoModel(url);
+    this->m_list << FMStatic::getFileInfoModel(url);
     emit this->postItemAppended();
 
     urls << url;
@@ -35,6 +33,18 @@ void HistoryModel::append(const QUrl &url)
     UTIL::saveSettings("URLS", QUrl::toStringList(urls), "HISTORY");
 }
 
+int HistoryModel::indexOfName(const QString &query)
+{
+  const auto it = std::find_if(this->items().constBegin(), this->items().constEnd(), [&](const FMH::MODEL &item) -> bool {
+          return item[FMH::MODEL_KEY::LABEL].startsWith(query, Qt::CaseInsensitive);
+      });
+
+      if (it != this->items().constEnd())
+          return this->mappedIndexFromSource(std::distance(this->items().constBegin(), it));
+      else
+          return -1;
+}
+
 QList<QUrl> HistoryModel::getHistory()
 {
     auto urls = UTIL::loadSettings("URLS", "HISTORY", QStringList()).toStringList();
@@ -51,8 +61,9 @@ void HistoryModel::setList()
             continue;
 
         emit this->preItemAppended();
-        this->m_list << FMH::getFileInfoModel(url);
+        this->m_list << FMStatic::getFileInfoModel(url);
         emit this->postItemAppended();
+        emit this->countChanged();
     }
 }
 
