@@ -3,13 +3,8 @@
 
 #include <QObject>
 
-#ifdef STATIC_MAUIKIT
-#include "fmh.h"
-#include "mauilist.h"
-#else
-#include <MauiKit/fmh.h>
-#include <MauiKit/mauilist.h>
-#endif
+#include <MauiKit/Core/fmh.h>
+#include <MauiKit/Core/mauilist.h>
 
 class HistoryModel : public MauiList
 {
@@ -24,6 +19,7 @@ public:
 
 public slots:
     void append(const QUrl &url);
+    int indexOfName(const QString &query);
 
 private:
     FMH::MODEL_LIST m_list;
